@@ -32,7 +32,7 @@ export class PatientOngoingPrescription extends Model {
     });
   }
 
-  static async buildSyncLookupQueryDetails() {
+  static buildSyncLookupQueryDetails() {
     return buildPatientLinkedLookupFilter(this);
   }
 
