@@ -193,7 +193,30 @@ encounter.delete('/:id', deleteEncounter);
 const encounterRelations = permissionCheckingRouter('read', 'Encounter');
 encounterRelations.get(
   '/:id/discharge',
-  simpleGetHasOne('Discharge', 'encounterId', { auditAccess: true }),
+  asyncHandler(async (req, res) => {
+    const {
+      models: { Discharge },
+      params,
+    } = req;
+    req.checkPermission('read', 'Discharge');
+
+    const discharge = await Discharge.findOne({
+      where: {
+        encounterId: params.id,
+      },
+      include: Discharge.getFullReferenceAssociations(),
+    });
+    if (!discharge) throw new NotFoundError();
+    await req.audit?.access?.({
+      recordId: discharge.id,
+      params,
+      model: Discharge,
+    });
+
+    const plain = discharge.get({ plain: true });
+    plain.address = await discharge.address();
+    res.send(plain);
+  }),
 );
 encounterRelations.get('/:id/legacyVitals', simpleGetList('Vitals', 'encounterId'));
 encounterRelations.get('/:id/diagnoses', simpleGetList('EncounterDiagnosis', 'encounterId'));
@@ -505,8 +528,8 @@ encounterRelations.delete('/:id/programResponses/:surveyResponseId', deleteSurve
 // Used in charts and vitals to query responses based on the date of a response answer
 async function getAnswersWithHistory(req) {
   const { db, params, query } = req;
-  const { id: encounterId, surveyId = null } = params;
-  const { order = 'DESC' } = query;
+  const { id: encounterId, surveyId = null} = params;
+  const { order = 'DESC', instanceId = null } = query;
 
   const isVitals = surveyId === null;
   const dateDataElement = isVitals
@@ -526,12 +549,14 @@ async function getAnswersWithHistory(req) {
       AND response.encounter_id = :encounterId
       AND response.deleted_at IS NULL
       AND CASE WHEN :surveyId IS NOT NULL THEN response.survey_id = :surveyId ELSE true END
+      AND CASE WHEN :instanceId IS NOT NULL THEN response.metadata->>'chartInstanceResponseId' = :instanceId ELSE true END
     `,
     {
       replacements: {
         encounterId,
         dateDataElement,
         surveyId,
+        instanceId,
       },
       type: QueryTypes.SELECT,
     },
@@ -556,6 +581,7 @@ async function getAnswersWithHistory(req) {
         AND response.encounter_id = :encounterId
         AND response.deleted_at IS NULL
         AND CASE WHEN :surveyId IS NOT NULL THEN response.survey_id = :surveyId ELSE true END
+        AND CASE WHEN :instanceId IS NOT NULL THEN response.metadata->>'chartInstanceResponseId' = :instanceId ELSE true END
         ORDER BY body ${order} LIMIT :limit OFFSET :offset
       ),
       history AS (
@@ -600,6 +626,7 @@ async function getAnswersWithHistory(req) {
         offset: page * rowsPerPage,
         dateDataElement,
         surveyId,
+        instanceId,
       },
       type: QueryTypes.SELECT,
     },
